package monnethic.mobile.demoConfig;

import android.app.ProgressDialog;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.Spinner;
import android.widget.Switch;
import android.widget.Toast;

import com.example.monnthic.monnethicmobile.R;

import java.util.ArrayList;
import java.util.List;

import monnethic.mobile.history.HistoryActivity;
import monnethic.mobile.restApi.Config;
import monnethic.mobile.restApi.ConfigApiHandler;

public class DemoConfig extends AppCompatActivity {
    private Spinner cSpinner;
    private Switch cSwitch;
    private Switch apiSwitch;
    private Button btnValidateConf;
    private Button btnCloseConf;
    private Button btnCheckConf;
    private String ENV;
    private String API;
    private String CHAINCODE;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_demo_config);

        initView();
    }

    private void initView(){
        buttonInit();
        switchEnvInit();
        switchApiInit();
        spinnerInit();
    }

    public void switchEnvInit(){
        cSwitch = findViewById(R.id.switchEnv);
        cSwitch.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                if(cSwitch.isChecked()){
                    ENV = "1";
                }else{
                    ENV = "0";
                }
            }
        });
    }

    public void switchApiInit(){
        apiSwitch = findViewById(R.id.switchApi);
        apiSwitch.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                if(apiSwitch.isChecked()){
                    API = "1";
                }else{
                    API = "0";
                }
            }
        });
    }

    public void spinnerInit(){
        cSpinner = findViewById(R.id.spinnerConfig);
        List<String> listOptions = new ArrayList<>();
        listOptions.add("CHAINCODE - PROD");
        listOptions.add("CHAINCODE - QA");
        listOptions.add("CHAINCODE - TEST");
        ArrayAdapter<String> adapterOptions = new ArrayAdapter<>(this,android.R.layout.simple_spinner_dropdown_item,listOptions);
        adapterOptions.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        cSpinner.setAdapter(adapterOptions);
    }

    public void buttonInit(){
        btnValidateConf = findViewById(R.id.buttonValidateConfig);
        btnValidateConf.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                switch (String.valueOf(cSpinner.getSelectedItem())){
                    case "CHAINCODE - PROD":
                        CHAINCODE = "0";
                        break;
                    case "CHAINCODE - QA":
                        CHAINCODE = "1";
                        break;
                    case "CHAINCODE - TEST":
                        CHAINCODE = "2";
                        break;
                }
                new updateConfigTask().execute(ENV,CHAINCODE);
            }
        });

        btnCheckConf = findViewById(R.id.buttonCheckConfig);
        btnCheckConf.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                new checkConfigTask().execute();
            }
        });

        btnCloseConf = findViewById(R.id.buttonCloseConfig);
        btnCloseConf.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });
    }

    private class updateConfigTask extends AsyncTask<String,String,String> {
        ProgressDialog progDailog = new ProgressDialog(DemoConfig.this);
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            progDailog.setMessage("Updating Config...");
            progDailog.setIndeterminate(false);
            progDailog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progDailog.setCancelable(true);
            progDailog.show();
        }

        @Override
        protected String doInBackground(String... strings) {
            try{
                String e = strings[0];
                String c = strings[1];

                ConfigApiHandler configApiHandler = new ConfigApiHandler();
                configApiHandler.updateEnvironment(e);
                configApiHandler.updateChaincode(c);
                Config.setAPI(API);
            }catch (Exception e){
                e.printStackTrace();
            }
            return null;
        }

        @Override
        protected void onPostExecute(String result) {
            progDailog.dismiss();
        }
    }

    private class checkConfigTask extends AsyncTask<String,String,String>{
        ProgressDialog progDailog = new ProgressDialog(DemoConfig.this);
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            progDailog.setMessage("Check Config...");
            progDailog.setIndeterminate(false);
            progDailog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progDailog.setCancelable(true);
            progDailog.show();
        }

        @Override
        protected String doInBackground(String... strings) {
            try{
                ConfigApiHandler configApiHandler = new ConfigApiHandler();
                String r = configApiHandler.getConfiguration();
                return r;
            }catch (Exception e){
                e.printStackTrace();
                return null;
            }
        }

        @Override
        protected void onPostExecute(String result) {
            progDailog.dismiss();
            Toast.makeText(DemoConfig.this, result+" - "+Config.getAPI(),Toast.LENGTH_SHORT).show();
        }
    }
}
