package monnethic.mobile.history;

import android.app.DatePickerDialog;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.DatePicker;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.Switch;
import android.widget.Toast;
import com.example.monnthic.monnethicmobile.R;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import monnethic.mobile.database.Transaction;
import monnethic.mobile.restApi.Config;
import monnethic.mobile.restApi.SessionApiHandler;
import monnethic.mobile.restApi.TransactionApiHandler;
import monnethic.mobile.transaction.TransactionAdapter;

public class HistoryActivity extends AppCompatActivity {
    private String wallet_hash;
    private String user_hash;
    private String user_password;
    private String session_id;

    final Calendar calendar1 = Calendar.getInstance();
    final Calendar calendar2 = Calendar.getInstance();
    private Button btnSearchTransactions;
    private EditText inputSize;
    private EditText fromDate;
    private EditText toDate;
    private Spinner spinner;
    private Switch aSwitch;
    private ListView listView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_history);

        getIntentValue();
        initView();
    }

    private void getIntentValue(){
        Intent intent = getIntent();
        user_hash = intent.getStringExtra("USER_HASH");
        user_password = intent.getStringExtra("USER_PWD");
        session_id = intent.getStringExtra("SESSION_ID");
        wallet_hash = intent.getStringExtra("WALLET_HASH");
    }

    private void initView(){
        inputSize = findViewById(R.id.inputSize);
        inputSize.setText(String.valueOf(10));
        dateInit();
        buttonInit();
        switchInit();
        spinnerInit();
        listViewHandler("0");
    }

    public void dateInit(){
        DatePickerDialog.OnDateSetListener fromDatePicker = new DatePickerDialog.OnDateSetListener() {
            @Override
            public void onDateSet(DatePicker datePicker, int year, int monthOfYear, int dayOfMonth) {
                calendar1.set(Calendar.YEAR, year);
                calendar1.set(Calendar.MONTH, monthOfYear);
                calendar1.set(Calendar.DAY_OF_MONTH, dayOfMonth);
                updateLabel(0);
            }
        };
        fromDate = findViewById(R.id.fromDate);
        fromDate.setEnabled(false);
        fromDate.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                new DatePickerDialog(HistoryActivity.this, fromDatePicker, calendar1.get(Calendar.YEAR),
                        calendar1.get(Calendar.MONTH), calendar1.get(Calendar.DAY_OF_MONTH)).show();
                //Toast.makeText(HistoryActivity.this,"Clicked fromDate",Toast.LENGTH_SHORT).show();
            }
        });

        DatePickerDialog.OnDateSetListener toDatePicker = new DatePickerDialog.OnDateSetListener() {
            @Override
            public void onDateSet(DatePicker datePicker, int year, int monthOfYear, int dayOfMonth) {
                calendar2.set(Calendar.YEAR, year);
                calendar2.set(Calendar.MONTH, monthOfYear);
                calendar2.set(Calendar.DAY_OF_MONTH, dayOfMonth);
                updateLabel(1);
            }
        };
        toDate = findViewById(R.id.toDate);
        toDate.setEnabled(false);
        toDate.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                new DatePickerDialog(HistoryActivity.this, toDatePicker, calendar2.get(Calendar.YEAR),
                        calendar2.get(Calendar.MONTH), calendar2.get(Calendar.DAY_OF_MONTH)).show();
            }
        });
    }

    public void updateLabel(int idDate){
        try{
            String myFormat = "dd-MM-yyyy";
            SimpleDateFormat sdf = new SimpleDateFormat(myFormat, Locale.FRANCE);
            if(idDate==0){
                fromDate.setText(sdf.format(calendar1.getTime()));
            }else {
                if(calendar2.getTime().before(calendar1.getTime())){
                    toDate.setText(sdf.format(calendar1.getTime()));
                }else {
                    toDate.setText(sdf.format(calendar2.getTime()));
                }
            }
        } catch (Exception e){
            e.printStackTrace();
        }

    }

    public void buttonInit(){
        btnSearchTransactions = findViewById(R.id.buttonSearchTransaction);
        btnSearchTransactions.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if(!aSwitch.isChecked()){
                    switch (String.valueOf(spinner.getSelectedItem())){
                        case "All":
                            listViewHandler("1");
                            break;
                        case "Sent":
                            listViewHandler("2");
                            break;
                        case "Received":
                            listViewHandler("3");
                            break;
                    }
                } else {
                    switch (String.valueOf(spinner.getSelectedItem())){
                        case "All":
                            listViewHandler("4");
                            break;
                        case "Sent":
                            listViewHandler("5");
                            break;
                        case "Received":
                            listViewHandler("6");
                            break;
                    }
                }
            }
        });

    }

    public void switchInit(){
        aSwitch = findViewById(R.id.switchDate);
        aSwitch.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                if(aSwitch.isChecked()){
                    fromDate.setEnabled(true);
                    toDate.setEnabled(true);
                }else{
                    fromDate.setEnabled(false);
                    toDate.setEnabled(false);
                }
            }
        });

    }

    public void spinnerInit(){
        spinner = findViewById(R.id.spinner);

        List<String> listOptions = new ArrayList<>();
        listOptions.add("All");
        listOptions.add("Received");
        listOptions.add("Sent");
        ArrayAdapter<String> adapterOptions = new ArrayAdapter<>(this,android.R.layout.simple_spinner_dropdown_item,listOptions);
        adapterOptions.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinner.setAdapter(adapterOptions);
    }

    public void listViewHandler(String function){
        listView = findViewById(R.id.listViewTransactions);
        ArrayList<Transaction> transactions = new ArrayList<>();
        //function, wallet_hash, size, start_date, end_date
        try{
            String size = inputSize.getText().toString();
            if(Integer.parseInt(function)==0){
                transactions = new getTransactionTask().execute(function,wallet_hash).get();
            } else if(Integer.parseInt(function)==1 || Integer.parseInt(function)==2 || Integer.parseInt(function)==3){
                transactions = new getTransactionTask().execute(function,wallet_hash,size).get();
            } else {
                String myFormat = "dd-MM-yyyy";
                SimpleDateFormat sdf = new SimpleDateFormat(myFormat, Locale.FRANCE);
                Date start_d = sdf.parse(fromDate.getText().toString());
                String start_date = String.valueOf(start_d.getTime());
                Date end_d = sdf.parse(toDate.getText().toString());
                String end_date = String.valueOf(end_d.getTime());
                transactions = new getTransactionTask().execute(function,wallet_hash,size,start_date,end_date).get();
            }
        }catch (Exception e){
            e.printStackTrace();
        }

        TransactionAdapter adapter = new TransactionAdapter(this,transactions,wallet_hash);
        listView.setAdapter(adapter);

        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                Transaction t = (Transaction) listView.getItemAtPosition(i);
                Intent transactionDetailsIntent = new Intent(HistoryActivity.this, HistoryDetailsActivity.class);
                transactionDetailsIntent.putExtra("USER_HASH",user_hash);
                transactionDetailsIntent.putExtra("USER_PWD",user_password);
                transactionDetailsIntent.putExtra("SESSION_ID",session_id);
                transactionDetailsIntent.putExtra("WALLET_HASH",wallet_hash);
                transactionDetailsIntent.putExtra("TRANSACTION",t);
                HistoryActivity.this.startActivity(transactionDetailsIntent);
            }
        });

    }

    private class getTransactionTask extends AsyncTask<String,ArrayList<Transaction>,ArrayList<Transaction>> {
        ProgressDialog progDailog = new ProgressDialog(HistoryActivity.this);
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            progDailog.setMessage("Searching...");
            progDailog.setIndeterminate(false);
            progDailog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progDailog.setCancelable(true);
            progDailog.show();
        }

        @Override
        protected void onPostExecute(ArrayList<Transaction> t) {
            progDailog.dismiss();
        }

        @Override
        protected ArrayList<Transaction> doInBackground(String... strings) {
            ArrayList<Transaction> transactionsList = new ArrayList<>();
            try{
                TransactionApiHandler transactionApiHandler = new TransactionApiHandler();
                switch (Integer.parseInt(strings[0])){
                    case 0:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_LATEST,strings[1],null,null,null);
                        break;
                    case 1:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_ALL,strings[1],strings[2],null,null);
                        break;
                    case 2:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_SENT,strings[1],strings[2],null,null);
                        break;
                    case 3:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_RECEIVED,strings[1],strings[2],null,null);
                        break;
                    case 4:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_ALL,strings[1],strings[2],strings[3],strings[4]);
                        break;
                    case 5:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_SENT,strings[1],strings[2],strings[3],strings[4]);
                        break;
                    case 6:
                        transactionsList = transactionApiHandler.getTransactions(strings[0],Config.TRANSACTION_RECEIVED,strings[1],strings[2],strings[3],strings[4]);
                        break;
                }
            }catch (Exception e){
                e.printStackTrace();
            }
            return transactionsList;
        }
    }

    @Override
    protected void onStop() {
        super.onStop();  // Always call the superclass method first
        new EndSessionTask().execute(session_id);
    }

    private class EndSessionTask extends AsyncTask<String,Void,Void> {
        @Override
        protected Void doInBackground(String... strings) {
            try{
                SessionApiHandler sessionApiHandler = new SessionApiHandler();
                sessionApiHandler.endSession(strings[0]);
            }catch (Exception e){
                e.printStackTrace();
            }
            return null;
        }
    }

}
