package monnethic.mobile.history;

import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import com.example.monnthic.monnethicmobile.R;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import monnethic.mobile.database.Transaction;
import monnethic.mobile.restApi.SessionApiHandler;

public class HistoryDetailsActivity extends AppCompatActivity {
    private String wallet_hash;
    private String user_hash;
    private String user_password;
    private String session_id;
    private Transaction transaction;

    private TextView txID;
    private TextView txDate;
    private TextView txFrom;
    private TextView txTo;
    private TextView txAmount;
    private TextView txUnit;
    private Button goToExplorer;
    private Button closeActivity;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_history_details);
        getIntentValue();
        initView();
    }

    private void getIntentValue(){
        Intent intent = getIntent();
        user_hash = intent.getStringExtra("USER_HASH");
        user_password = intent.getStringExtra("USER_PWD");
        session_id = intent.getStringExtra("SESSION_ID");
        wallet_hash = intent.getStringExtra("WALLET_HASH");
        transaction = (Transaction) intent.getSerializableExtra("TRANSACTION");
    }

    private void initView(){
        txID = findViewById(R.id.displayTxID);
        txID.setText(transaction.getTransactionHash());

        Log.i("HistoryDetails","transaction : "+transaction.toString());
        Log.i("HistoryDetails","transaction Date : "+transaction.getTransactionDate());

        txDate = findViewById(R.id.dateDisplay);
        String myFormat = "dd-MM-yyyy HH:mm:ss";
        SimpleDateFormat sdf = new SimpleDateFormat(myFormat, Locale.FRANCE);
        Date dateTransaction = new Date(transaction.getTransactionDate());
        txDate.setText(sdf.format(dateTransaction));

        txFrom = findViewById(R.id.fromDisplay);
        txFrom.setText(transaction.getTransactionFrom());

        txTo = findViewById(R.id.toDisplay);
        txTo.setText(transaction.getTransactionTo());

        txAmount = findViewById(R.id.amountDisplay);
        String amountDisplay = String.valueOf(transaction.getTransactionAmount())+" "+transaction.getTransactionUnit();
        txAmount.setText(amountDisplay);

        goToExplorer = findViewById(R.id.btnGoToExplorer);
        closeActivity = findViewById(R.id.btnCloseDetails);

        setButtonListener();
    }

    private void setButtonListener(){
        goToExplorer.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                String url = "http://monitor.monnethic.fr:8080/#/transactions";
                Intent i = new Intent(Intent.ACTION_VIEW);
                i.setData(Uri.parse(url));
                startActivity(i);
            }
        });

        closeActivity.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });
    }


    @Override
    protected void onStop() {
        super.onStop();  // Always call the superclass method first
        new EndSessionTask().execute(session_id);
    }

    private class EndSessionTask extends AsyncTask<String,Void,Void> {
        @Override
        protected Void doInBackground(String... strings) {
            try{
                SessionApiHandler sessionApiHandler = new SessionApiHandler();
                sessionApiHandler.endSession(strings[0]);
            }catch (Exception e){
                e.printStackTrace();
            }
            return null;
        }
    }
}
