package monnethic.mobile.search;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
import com.example.monnthic.monnethicmobile.R;
import monnethic.mobile.database.User;
import monnethic.mobile.homepage.InputController;
import monnethic.mobile.restApi.SessionApiHandler;
import monnethic.mobile.restApi.UserApiHandler;

public class SearchUser extends AppCompatActivity {
    EditText emailAddress;
    EditText phoneNumber;
    Button buttonCancel;
    Button buttonOk;
    private String session_id;
    private String user_hash;
    private String user_password;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_search_user);

        Intent intent = getIntent();
        user_hash = intent.getStringExtra("USER_HASH");
        user_password = intent.getStringExtra("USER_PWD");
        session_id = intent.getStringExtra("SESSION_ID");

        initView();
    }

    private void initView(){
        emailAddress = findViewById(R.id.inputEmailSearch);
        phoneNumber = findViewById(R.id.inputPhoneSearch);
        buttonCancel = findViewById(R.id.buttonCancelSearch);
        buttonOk = findViewById(R.id.buttonOkSearch);

        buttonCancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                setResult(2);
                finish();
            }
        });

        buttonOk.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                search();
            }
        });
    }

    private void search(){
        String uEmail = emailAddress.getText().toString();
        String uPhone = phoneNumber.getText().toString();

        if(InputController.isEmptyEdit(emailAddress) && InputController.isEmptyEdit(phoneNumber)){
            Toast.makeText(this, "Enter an email or phone number", Toast.LENGTH_SHORT).show();
        } else if(InputController.isEmptyEdit(emailAddress)){
            new SearchUserTask(this).execute(null,uPhone);
        } else if(InputController.isEmptyEdit(phoneNumber)){
            new SearchUserTask(this).execute(uEmail,null);
        } else {
            new SearchUserTask(this).execute(uEmail,uPhone);
        }
    }

    private class SearchUserTask extends AsyncTask<String,Void,User> {
        Context mContext;
        private SearchUserTask(final Context context){mContext=context;}
        ProgressDialog progDailog = new ProgressDialog(SearchUser.this);
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            progDailog.setMessage("Searching user...");
            progDailog.setIndeterminate(false);
            progDailog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progDailog.setCancelable(true);
            progDailog.show();
        }

        @Override
        protected void onPostExecute(User user) {
            try{
                progDailog.dismiss();
                if(user!=null){
                    Intent displayWalletIntent = new Intent(SearchUser.this, DisplayWalletSearch.class);
                    displayWalletIntent.putExtra("user_name",user.getName());
                    displayWalletIntent.putExtra("user_firstname",user.getFirstname());
                    displayWalletIntent.putExtra("user_hash",user.getUser_hash());
                    displayWalletIntent.putExtra("SESSION_ID",session_id);
                    displayWalletIntent.addFlags(Intent.FLAG_ACTIVITY_FORWARD_RESULT);
                    SearchUser.this.startActivity(displayWalletIntent);
                    finish();
                }else{
                    Toast.makeText(mContext,"User dosen't exist",Toast.LENGTH_SHORT).show();
                }

            }catch (Exception e){
                e.printStackTrace();
            }
        }

        @Override
        protected User doInBackground(String... strings) {
            try {
                UserApiHandler userApiHandler = new UserApiHandler();
                User u = new User();
                if(strings[0]!=null && strings[1]==null){
                    u = userApiHandler.getUser(1,strings[0],null);
                } else if(strings[0]==null && strings[1]!=null){
                    u = userApiHandler.getUser(2,null,strings[1]);
                } else {
                    u = userApiHandler.getUser(3,strings[0],strings[1]);
                }
                return u;
            }catch (Exception e){
                e.printStackTrace();
            }
            return null;
        }

    }

    @Override
    protected void onStop() {
        super.onStop();  // Always call the superclass method first
        new EndSessionTask().execute(session_id);
    }

    private class EndSessionTask extends AsyncTask<String,Void,Void> {
        @Override
        protected Void doInBackground(String... strings) {
            try{
                SessionApiHandler sessionApiHandler = new SessionApiHandler();
                sessionApiHandler.endSession(strings[0]);
            }catch (Exception e){
                e.printStackTrace();
            }
            return null;
        }
    }
}
