package monnethic.mobile.wallet;

import android.app.ProgressDialog;
import android.content.Intent;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import com.example.monnthic.monnethicmobile.R;

import org.json.JSONObject;

import monnethic.mobile.database.User;
import monnethic.mobile.restApi.SessionApiHandler;
import monnethic.mobile.restApi.UserApiHandler;

public class HomeWalletActivity extends AppCompatActivity {
    private String user_hash;
    private String user_password;
    private String session_id;
    private String email;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_home_wallet);
        Button buttonCreateWallet = findViewById(R.id.buttonCreateWallet);
        Button buttonSelectWallet = findViewById(R.id.buttonSelectWallet);
        Button buttonApproveUser = findViewById(R.id.buttonApproveUser);

        Intent intent = getIntent();
        user_hash = intent.getStringExtra("USER_HASH");
        user_password = intent.getStringExtra("USER_PWD");
        session_id = intent.getStringExtra("SESSION_ID");
        email = intent.getStringExtra("email");

        buttonCreateWallet.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                launchCreateWalletActivity();
            }
        });

        buttonSelectWallet.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                launchSelectWalletActivity();
            }
        });

        buttonApproveUser.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                approveUser();
            }
        });
    }

    public void launchCreateWalletActivity() {
        try{
            Boolean approved = new CheckApprovalTask().execute(user_hash,email).get();

            if(approved){
                Intent createWalletIntent = new Intent(HomeWalletActivity.this, CreateWalletActivity.class);
                createWalletIntent.putExtra("USER_HASH",user_hash);
                createWalletIntent.putExtra("USER_PWD",user_password);
                createWalletIntent.putExtra("SESSION_ID",session_id);
                HomeWalletActivity.this.startActivity(createWalletIntent);
            }else{
                Toast.makeText(HomeWalletActivity.this,"You are not approved",Toast.LENGTH_SHORT).show();
            }
        } catch (Exception e){
            e.printStackTrace();
        }
    }

    public void launchSelectWalletActivity() {
        try{
            Boolean approved = new CheckApprovalTask().execute(user_hash,email).get();
            if(approved){
                Intent selectWalletIntent = new Intent(HomeWalletActivity.this, SelectWalletActivity.class);
                selectWalletIntent.putExtra("USER_HASH",user_hash);
                selectWalletIntent.putExtra("USER_PWD",user_password);
                selectWalletIntent.putExtra("SESSION_ID",session_id);
                HomeWalletActivity.this.startActivity(selectWalletIntent);
            }else {
                Toast.makeText(HomeWalletActivity.this,"You are not approved",Toast.LENGTH_SHORT).show();
            }
        }catch (Exception e){
            e.printStackTrace();
        }
    }

    public void approveUser(){
        new ApproveTask().execute(user_hash,email);
    }

    @Override
    protected void onStop() {
        super.onStop();  // Always call the superclass method first
        new EndSessionTask().execute(session_id);
    }

    private class EndSessionTask extends AsyncTask<String,Void,Void> {
        @Override
        protected Void doInBackground(String... strings) {
            try{
                SessionApiHandler sessionApiHandler = new SessionApiHandler();
                sessionApiHandler.endSession(strings[0]);
            }catch (Exception e){
                e.printStackTrace();
            }
            return null;
        }
    }

    private class CheckApprovalTask extends AsyncTask<String,Boolean,Boolean>{
        ProgressDialog progDailog = new ProgressDialog(HomeWalletActivity.this);
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            progDailog.setMessage("Loading...");
            progDailog.setIndeterminate(false);
            progDailog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progDailog.setCancelable(true);
            progDailog.show();
        }

        @Override
        protected Boolean doInBackground(String... strings) {
            try{
                UserApiHandler userApiHandler = new UserApiHandler();
                return userApiHandler.checkApproval(strings[0],strings[1]);
            }catch (Exception e){
                return null;
            }
        }

        @Override
        protected void onPostExecute(Boolean result) {
            progDailog.dismiss();
        }
    }

    private class ApproveTask extends AsyncTask<String,String,String>{
        ProgressDialog progDailog = new ProgressDialog(HomeWalletActivity.this);
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            progDailog.setMessage("Loading...");
            progDailog.setIndeterminate(false);
            progDailog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progDailog.setCancelable(true);
            progDailog.show();
        }

        @Override
        protected void onPostExecute(String result) {
            progDailog.dismiss();
        }

        @Override
        protected String doInBackground(String... strings) {
            try{
                UserApiHandler userApiHandler = new UserApiHandler();
                userApiHandler.approveUser(strings[0],strings[1]);
                return null;
            }catch (Exception e){
                e.printStackTrace();
                return null;
            }
        }
    }
}